<?php

namespace App\Filament\Resources;

use App\Filament\Resources\DeploymentApplicationResource\Pages;
use App\Filament\Resources\DeploymentApplicationResource\RelationManagers;
use App\Models\DeploymentApplication;
use App\Models\DeploymentOpportunity;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

use Filament\Tables\Filters\SelectFilter;

class DeploymentApplicationResource extends Resource
{
    protected static ?string $model = DeploymentApplication::class;
    
    
    public static function getModelLabel(): string
    {
        return __('deploymentApplication.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('deployment_opportunity_id')
                     ->relationship('deployment_opportunity', 'event_name')
                     ->label(__('deploymentApplication.deploymentopportunity')),
                     //->options(DeploymentOpportunity::where('user_id',NULL)->pluck('event_name','id')),
                Forms\Components\Select::make('status')
                     ->label(__('deploymentApplication.status'))
                    ->options([
                        'Pending' => 'Pending',
                        'Approved' => 'Approved',
                        'Denied' => 'Denied'
                ])
                ->hidden(! auth()->user()->hasAnyRole('Admin'))
                ->default('pending')
                ->saveRelationshipsWhenHidden()
                ->label(__('deploymentApplication.status')),
                
                Forms\Components\Select::make('user')
                ->label(__('deploymentApplication.user'))
                ->relationship('user_data', 'name')
                //->multiple()
                ->preload()
                ->hidden(! auth()->user()->hasAnyRole('Admin')) 
                ->label(__('deploymentApplication.user'))              
                
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
        ->columns([
            Tables\Columns\TextColumn::make('id')
            ->label(__('ID'))
            ->numeric()
            ->sortable()
            ->hidden(!auth()->user()->hasAnyRole('Admin')),
            Tables\Columns\TextColumn::make('deployment_opportunity.event_name')
            ->label(__('deploymentApplication.deploymentopportunity'))
            ->numeric()
            ->sortable(),
                Tables\Columns\TextColumn::make('user_data.name')
                    ->label(__('deploymentApplication.user'))
                    ->numeric()
                    ->sortable()
                    ->searchable(),
                    //->hidden(! auth()->user()->hasAnyRole('Admin')),
                
                    Tables\Columns\TextColumn::make('status')
                    ->label(__('deploymentApplication.status'))
                    ->badge()
                    ->colors([
                        'primary',
                        'warning' => 'Pending',
                        'success' => 'Approved',
                        'danger' => 'Denied'
                    ])
                    ->searchable(),
                    Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            
            ->filters([
                SelectFilter::make('deployment_opportunity')
                    ->relationship('deployment_opportunity', 'event_name')
            ])
            ->actions([
                // Tables\Actions\EditAction::make()
                // ->hidden(! auth()->user()->hasAnyRole('Admin')),
                // TODO: add email and notification on edit
                Tables\Actions\ViewAction::make(),
                
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            // RelationManagers\DeploymentOpportunityRelationManager::class,
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListDeploymentApplications::route('/'),
            'create' => Pages\CreateDeploymentApplication::route('/create'),
            'edit' => Pages\EditDeploymentApplication::route('/{record}/edit'),
        ];
    }    
}
