<?php

namespace App\Filament\Resources;

use App\Filament\Resources\DeploymentOpportunityResource\Pages;
use App\Mail\ApplicationMail;
use App\Models\DeploymentApplication;
use App\Models\DeploymentOpportunity;
use App\Models\RequestDatabase;
use App\Models\User;
use Filament\Actions\Action;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Filament\Infolists\Infolist;
use Filament\Infolists\Components\TextEntry;
use Filament\Infolists\Components\Fieldset;
use App\Mail\ApplicationRecievedMail;
use Filament\Resources\RelationManagers\RelationManager;
use App\Filament\Resources\DeploymentOpportunityResource\RelationManagers;
use Illuminate\Support\Facades\Mail;
use Filament\Notifications\Notification;

use Mohamedsabil83\FilamentFormsTinyeditor\Components\TinyEditor;


class DeploymentOpportunityResource extends Resource
{
    protected static ?string $model = DeploymentOpportunity::class;
    public static function getModelLabel(): string
    
    {
        return __('deploymentOpportunity.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';

    

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('request_id')
                    ->label(__('deploymentOpportunity.request'))
                    ->options(RequestDatabase::where('request_approval','Approved')->pluck('request_name','id'))
                    ->required(),
                Forms\Components\TextInput::make('event_name')
                     ->label(__('deploymentOpportunity.event_name'))
                    ->maxLength(255),
                Forms\Components\Select::make('logistics_administrator_id')
                    ->label(__('deploymentOpportunity.logistics_administrator'))
                    ->relationship('logistics_administrator', 'name')
                    ->required(),
                TinyEditor::make('narrative')
                    ->label(__('register.narrative'))
                    ->columnSpanFull(),
                Forms\Components\Select::make('location_province_region_id')
                    ->label(__('deploymentOpportunity.location_province_region'))
                    ->relationship('location_province_region', 'name')
                    ->required(),
                Forms\Components\TextInput::make('posting_number')
                    ->label(__('deploymentOpportunity.posting_number'))
                    ->numeric(),
                Forms\Components\Select::make('deployment_role')
                    ->label(__('requestDatabase.requestType'))
                    ->relationship('deployment_role', 'name')
                    ->multiple()
                    ->preload(),

                Forms\Components\DatePicker::make('expected_deployment_start_date')
                    ->label(__('deploymentOpportunity.expected_deployment_start_date')),
                Forms\Components\DatePicker::make('actual_deployment_start_date')
                    ->label(__('deploymentOpportunity.actual_deployment_start_date')),
                Forms\Components\DatePicker::make('expected_deployment_end_date')
                    ->label(__('deploymentOpportunity.expected_deployment_end_date')),
                Forms\Components\DatePicker::make('actual_deployment_end_date')
                    ->label(__('deploymentOpportunity.actual_deployment_end_date')),
                Forms\Components\TextInput::make('number_of_deployers')
                    ->label(__('deploymentOpportunity.number_of_deployers'))
                    ->numeric(),
                Forms\Components\TextInput::make('location_city')
                    ->label(__('deploymentOpportunity.location_city'))
                    ->maxLength(255),
                TinyEditor::make('language_required')
                    ->label(__('deploymentOpportunity.language_required'))
                    ->columnSpanFull(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('id')
                    ->label(__('ID'))
                    ->sortable(),
                Tables\Columns\TextColumn::make('event_name')
                    ->label(__('deploymentOpportunity.event_name'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('request.request_name')
                    ->label(__('deploymentOpportunity.request'))
                    ->numeric()
                    ->sortable()
                    ->wrap(),
                Tables\Columns\TextColumn::make('location_province_region.name')
                    ->label(__('deploymentOpportunity.location_province_region'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('deployment_role.name')
                    ->label(__('Deployment Role/s'))
                    ->numeric()
                    ->sortable()
                    ->searchable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('logistics_administrator.name')
                    ->label(__('deploymentOpportunity.logistics_administrator'))
                    ->numeric()
                    ->sortable()
                    ->searchable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('posting_number')
                ->label(__('deploymentOpportunity.deployer_position_title'))
                    ->numeric()
                    ->sortable()
                    ->searchable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deployer_position_title')
                    ->searchable()->toggleable(isToggledHiddenByDefault: true)
                    ->wrap(),
                Tables\Columns\TextColumn::make('expected_deployment_start_date')
                    ->label(__('deploymentOpportunity.expected_deployment_start_date'))
                    ->date()
                    ->sortable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('actual_deployment_start_date')
                    ->label(__('deploymentOpportunity.actual_deployment_start_date'))
                    ->date()
                    ->sortable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('expected_deployment_end_date')
                    ->label(__('deploymentOpportunity.expected_deployment_end_date'))
                    ->date()
                    ->sortable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('actual_deployment_end_date')
                    ->label(__('deploymentOpportunity.actual_deployment_end_date'))
                
                    ->date()
                    ->sortable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('number_of_deployers')
                    ->label(__('deploymentOpportunity.number_of_deployers'))
                    ->numeric()
                    ->sortable()->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('location_city')
                    ->label(__('deploymentOpportunity.location_city'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('location_city')
                    ->label(__('deploymentOpportunity.language_required'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                    Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->defaultSort('id', 'desc')
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\ViewAction::make(),
                Tables\Actions\EditAction::make()
                ->hidden(!auth()->user()->hasAnyRole('Admin')),
                // Appl for opportunity action
                Tables\Actions\Action::make('Apply')
                ->action(function (DeploymentOpportunity $record) {                    
                    $user = auth()-f>user();
                    $applicationData = [
                        'deployment_opportunity_id' => $record->id,
                        'user_id' => $user->id,
                        
                    ];
                    // Update or create the deployment application record
                    $deployment_application = DeploymentApplication::updateOrCreate(
                        $applicationData,
                        $applicationData
                    );
                    $deploymentApplication = DeploymentApplication::find($deployment_application->id);

                    if (!$deploymentApplication->user()->find($user->id)) {
                        
                        $deploymentApplication->user()->attach($user->id);
                        // $depName = $deploymentApplication->name;
                        // $userName = $user->name;
                        // Mail::to($user->email)
                        //     ->cc(User::role('Admin')->get())
                        //     ->send(new ApplicationMail($depName, $userName ));                        

                        // return redirect('http://localhost:4322/admin/deployment-applications');                       
                    }

                })
                ->requiresConfirmation()
                ->after(function(DeploymentOpportunity $record){
                    $user = auth()->user();
                    Notification::make()
                        ->title('Application Received')
                        ->body('Your application for ' . $record->event_name . ' has been received.')
                        ->sendToDatabase($user); 
                    // Works
                    Mail::to($user->email)
                        ->cc(User::role('Admin')->get())
                        ->send(new ApplicationRecievedMail($record->event_name, $user->name));
                    
                    Notification::make()
                        ->success()
                        ->title( $user->name . 'has applied to'. $record->event_name )
                        ->icon('heroicon-o-document-text') 
                        ->iconColor('success') 
                        ->body($user->name . ' has applied to'. $record->event_name . 'and the current status is pending')
                        ->sendToDatabase(User::role('Admin')->get()); 

                })
                ->hidden(auth()->user()->hasAnyRole('Admin')),
            
            ])
            
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
                Tables\Actions\DeleteAction::make(),
            ]);
            
    }
    
    public static function getRelations(): array
    {
        return [
            RelationManagers\DeploymentApplicationRelationManager::class,
            RelationManagers\AdminUserDeploymentApplicationRelationManager::class

        ];
    }
    
    public static function infolist(Infolist $infolist): Infolist
    {
        return $infolist
            ->schema([
                TextEntry::make('event_name')
                    ->label(__('deploymentOpportunity.event_name')),
                TextEntry::make('request.request_name')
                    ->label(__('deploymentOpportunity.request')),
                TextEntry::make('location_province_region.name')
                    ->label(__('deploymentOpportunity.location_province_region')),
                TextEntry::make('logistics_administrator.name')
                    ->label(__('deploymentOpportunity.logistics_administrator')),
                TextEntry::make('posting_number')
                    ->label(__('deploymentOpportunity.deployer_position_title')),
                TextEntry::make('deployer_position_title'),
                 TextEntry::make('narrative')
                    ->label(__('narrative'))
                    ->columnSpanFull(),
                Fieldset::make(__('deploymentOpportunity.key_dates'))
                    ->schema([
                        TextEntry::make('expected_deployment_start_date')
                            ->label(__('deploymentOpportunity.expected_deployment_start_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        TextEntry::make('actual_deployment_start_date')
                            ->label(__('deploymentOpportunity.actual_deployment_start_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        TextEntry::make('expected_deployment_end_date')
                            ->label(__('deploymentOpportunity.expected_deployment_end_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        TextEntry::make('actual_deployment_end_date')
                            ->label(__('deploymentOpportunity.actual_deployment_end_date'))
                            ->badge()
                            ->dateTime('d/m/Y'),
                        
                    ]),
                
                TextEntry::make('number_of_deployers')
                    ->label(__('deploymentOpportunity.number_of_deployers')),
                TextEntry::make('location_city')
                    ->label(__('deploymentOpportunity.location_city')),
                TextEntry::make('location_city')
                    ->label(__('deploymentOpportunity.language_required')),
            ]);
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListDeploymentOpportunities::route('/'),
            'create' => Pages\CreateDeploymentOpportunity::route('/create'),
            'edit' => Pages\EditDeploymentOpportunity::route('/{record}/edit'),
            'view' => Pages\ViewDeploymentOpportunity::route('/{record}'),
        ];
    }    
}
