<?php

namespace App\Filament\Resources;

use App\Filament\Resources\EmergencyLogisticResource\Pages;
use App\Filament\Resources\EmergencyLogisticResource\RelationManagers;
use App\Models\EmergencyLogistic;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class EmergencyLogisticResource extends Resource
{
    protected static ?string $model = EmergencyLogistic::class;
    public static function getModelLabel(): string
    {
        return __('emergencyLogistic.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('shipping_and_receiving_id')
                    ->label(__('emergencyLogistic.shipping_and_receiving'))
                    ->relationship('shipping_and_receiving', 'name')
                    ->required(),
                Forms\Components\Select::make('sample_packaging_id')
                    ->label(__('emergencyLogistic.sample_packaging'))
                    ->relationship('sample_packaging', 'name')
                    ->required(),
                Forms\Components\Select::make('inventory_management_id')
                    ->label(__('emergencyLogistic.inventory_management'))
                    ->relationship('inventory_management', 'name')
                    ->required(),
                Forms\Components\Select::make('travel_coordinator_id')
                    ->label(__('emergencyLogistic.travel_coordinator'))
                    ->relationship('travel_coordinator', 'name')
                    ->required(),
                Forms\Components\Select::make('fleet_management_id')
                    ->label(__('emergencyLogistic.fleet_management'))
                    ->relationship('fleet_management', 'name')
                    ->required(),
                Forms\Components\Select::make('moving_resources_to_the_field_id')
                    ->label(__('emergencyLogistic.moving_resources_to_the_field'))
                    ->relationship('moving_resources_to_the_field', 'name')
                    ->required(),
                Forms\Components\Select::make('deployer_training_resources_id')
                    ->label(__('emergencyLogistic.deployer_training_resources'))
                    ->relationship('deployer_training_resources', 'name')
                    ->required(),
                Forms\Components\Select::make('eoc_logistics_emergency_operations_center_id')
                    ->label(__('emergencyLogistic.eoc_logistics_emergency_operations_center'))
                    ->relationship('eoc_logistics_emergency_operations_center', 'name')
                    ->required(),
                // Forms\Components\Select::make('user_id')
                //     ->relationship('psychiatrist', 'name')
                //     ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('shipping_and_receiving.name')
                    ->label(__('emergencyLogistic.shipping_and_receiving'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('sample_packaging.name')
                    ->label(__('emergencyLogistic.sample_packaging'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('inventory_management.name')
                    ->label(__('emergencyLogistic.inventory_management'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('travel_coordinator.name')
                    ->label(__('emergencyLogistic.travel_coordinator'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('fleet_management.name')
                    ->label(__('emergencyLogistic.fleet_management'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('moving_resources_to_the_field.name')
                    ->label(__('emergencyLogistic.moving_resources_to_the_field'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('deployer_training_resources.name')
                    ->label(__('emergencyLogistic.deployer_training_resources'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('eoc_logistics_emergency_operations_center.name')
                    ->label(__('emergencyLogistic.eoc_logistics_emergency_operations_center'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                    Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListEmergencyLogistics::route('/'),
            // 'create' => Pages\CreateEmergencyLogistic::route('/create'),
            // 'edit' => Pages\EditEmergencyLogistic::route('/{record}/edit'),
        ];
    }    
}
