<?php

namespace App\Filament\Resources;

use App\Filament\Resources\ExperienceInEpidemiologyResource\Pages;
use App\Filament\Resources\ExperienceInEpidemiologyResource\RelationManagers;
use App\Models\ExperienceInEpidemiology;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class ExperienceInEpidemiologyResource extends Resource
{
    protected static ?string $model = ExperienceInEpidemiology::class;

    public static function getModelLabel(): string
    {
        return __('experienceInEpidemiology.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('rapid_risk_assessments_id')
                    ->label(__('experienceInEpidemiology.rapid_risk_assessments'))
                    ->relationship('rapid_risk_assessments', 'name')
                    ->required(),
                Forms\Components\Select::make('monitoring_system_id')
                    ->label(__('experienceInEpidemiology.monitoring_and_evaluation'))
                    ->relationship('monitoring_system', 'name')
                    ->required(),
                Forms\Components\Select::make('epidemic_survey_id')
                    ->label(__('caseManagement.epidemic_survey'))
                    ->relationship('epidemic_survey', 'name')
                    ->required(),
                Forms\Components\Select::make('determination_of_disease_status_id')
                    ->label(__('experienceInEpidemiology.disease_surveillance'))
                    ->relationship('determination_of_disease_status', 'name')
                    ->required(),
                Forms\Components\Select::make('contact_tracing_id')
                    ->label(__('experienceInEpidemiology.contact_tracing'))
                    ->relationship('contact_tracing', 'name')
                    ->required(),
                Forms\Components\Select::make('case_management_id')
                    ->label(__('experienceInEpidemiology.case_management'))
                    ->relationship('case_management', 'name')
                    ->required(),
                Forms\Components\Select::make('epidemiological_studies_id')
                    ->label(__('experienceInEpidemiology.epidemiological_studies'))
                    ->relationship('epidemiological_studies', 'name')
                    ->required(),
                Forms\Components\Select::make('study_protocols_id')
                    ->label(__('experienceInEpidemiology.study_protocols'))
                    ->relationship('study_protocols', 'name')
                    ->required(),
            ]);
                
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('rapid_risk_assessments.name')
                    ->numeric()
                    ->sortable()
                    ->label(__('experienceInEpidemiology.rapid_risk_assessments')),
                Tables\Columns\TextColumn::make('monitoring_system.name')
                    ->numeric()
                    ->sortable()
                    ->label(__('experienceInEpidemiology.monitoring_and_evaluation')),
                Tables\Columns\TextColumn::make('epidemic_survey.name')
                    ->label(__('caseManagement.epidemic_survey'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('determination_of_disease_status.name')
                    ->label(__('experienceInEpidemiology.disease_surveillance'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('contact_tracing.name')
                    ->label(__('experienceInEpidemiology.contact_tracing'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('case_management.name')
                    ->label(__('experienceInEpidemiology.case_management'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('epidemiological_studies.name')
                    ->label(__('experienceInEpidemiology.epidemiological_studies'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('study_protocols.name')
                    ->label(__('experienceInEpidemiology.study_protocols'))
                    ->numeric()
                    ->sortable(),
               
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListExperienceInEpidemiologies::route('/'),
            // 'create' => Pages\CreateExperienceInEpidemiology::route('/create'),
            // 'edit' => Pages\EditExperienceInEpidemiology::route('/{record}/edit'),
        ];
    }    
}
