<?php

namespace App\Filament\Resources;

use App\Filament\Resources\HazardousMaterialsExperienceResource\Pages;
use App\Filament\Resources\HazardousMaterialsExperienceResource\RelationManagers;
use App\Models\HazardousMaterialsExperience;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class HazardousMaterialsExperienceResource extends Resource
{
    protected static ?string $model = HazardousMaterialsExperience::class;
    public static function getModelLabel(): string
        {
            return __('hazardousMaterialsExperience.title');
        }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('certified_hazardous_materials_manager_chmm_id')
                    ->label(__('hazardousMaterialsExperience.certified_hazardous_materials_manager_chmm'))
                    ->relationship('certified_hazardous_materials_manager_chmm', 'name')
                    ->required(),
                Forms\Components\Select::make('certified_industrial_hygienist_cih_id')
                    ->label(__('hazardousMaterialsExperience.certified_industrial_hygienist_cih'))
                    ->relationship('certified_industrial_hygienist_cih', 'name')
                    ->required(),
                Forms\Components\Select::make('hazmat_specialist_training_id')
                    ->label(__('hazardousMaterialsExperience.hazmat_specialist_training'))
                    ->relationship('hazmat_specialist_training', 'name')
                    ->required(),
                Forms\Components\Select::make('record_keeping_id')
                    ->label(__('hazardousMaterialsExperience.record_keeping'))
                    ->relationship('record_keeping', 'name')
                    ->required(),
                Forms\Components\Select::make('hazardous_materials_management_y_n_program_id')
                    ->label(__('hazardousMaterialsExperience.hazardous_materials_management_y_n_program'))
                    ->relationship('hazardous_materials_management_y_n_program', 'name')
                    ->required(),
                Forms\Components\Select::make('medical_waste_plans_id')
                    ->label(__('hazardousMaterialsExperience.medical_waste_plans'))
                    ->relationship('medical_waste_plans', 'name')
                    ->required(),
                Forms\Components\Select::make('spill_response_plans_id')
                    ->label(__('hazardousMaterialsExperience.spill_response_plans'))
                    ->relationship('spill_response_plans', 'name')
                    ->required(),
                Forms\Components\Select::make('hazardous_waste_reduction_plans_id')
                    ->label(__('hazardousMaterialsExperience.hazardous_waste_reduction_plans'))
                    ->relationship('hazardous_waste_reduction_plans', 'name')
                    ->required(),
                Forms\Components\Select::make('hazardous_waste_contingency_plans_id')
                    ->label(__('hazardousMaterialsExperience.hazardous_waste_contingency_plans'))
                    ->relationship('hazardous_waste_contingency_plans', 'name')
                    ->required(),
                Forms\Components\Select::make('stormwater_y_n_plans_id')
                    ->label(__('hazardousMaterialsExperience.stormwater_y_n_plans'))
                    ->relationship('stormwater_y_n_plans', 'name')
                    ->required(),
                Forms\Components\Select::make('occupational_health_and_safety_y_n_programs_id')
                    ->label(__('hazardousMaterialsExperience.occupational_health_and_safety_y_n_programs'))
                    ->relationship('occupational_health_and_safety_y_n_programs', 'name')
                    ->required(),
                Forms\Components\Select::make('radiation_protection_plan_id')
                    ->label(__('hazardousMaterialsExperience.radiation_protection_plan'))
                    ->relationship('radiation_protection_plan', 'name')
                    ->required(),
                Forms\Components\Select::make('collection_hazardous_waste_id')
                    ->label(__('hazardousMaterialsExperience.collection_hazardous_waste'))
                    ->relationship('collection_hazardous_waste', 'name')
                    ->required(),
                Forms\Components\Select::make('training_others_on_hazardous_waste_id')
                    ->label(__('hazardousMaterialsExperience.training_others_on_hazardous_waste'))
                    ->relationship('training_others_on_hazardous_waste', 'name')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('certified_hazardous_materials_manager_chmm.name')
                    ->label(__('hazardousMaterialsExperience.certified_hazardous_materials_manager_chmm'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('certified_industrial_hygienist_cih.name')
                    ->label(__('hazardousMaterialsExperience.certified_industrial_hygienist_cih'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('hazmat_specialist_training.name')
                    ->label(__('hazardousMaterialsExperience.hazmat_specialist_training'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('record_keeping.name')
                    ->label(__('hazardousMaterialsExperience.record_keeping'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('hazardous_materials_management_y_n_program.name')
                    ->label(__('hazardousMaterialsExperience.hazardous_materials_management_y_n_program'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('medical_waste_plans.name')
                    ->label(__('hazardousMaterialsExperience.medical_waste_plans'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('spill_response_plans.name')
                    ->label(__('hazardousMaterialsExperience.spill_response_plans'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('hazardous_waste_reduction_plans.name')
                    ->label(__('hazardousMaterialsExperience.hazardous_waste_reduction_plans'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('hazardous_waste_contingency_plans.name')
                    ->label(__('hazardousMaterialsExperience.hazardous_waste_contingency_plans'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('stormwater_y_n_plans.name')
                    ->label(__('hazardousMaterialsExperience.stormwater_y_n_plans'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('occupational_health_and_safety_y_n_programs.name')
                    ->label(__('hazardousMaterialsExperience.occupational_health_and_safety_y_n_programs'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('radiation_protection_plan.name')
                    ->label(__('hazardousMaterialsExperience.radiation_protection_plan'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('collection_hazardous_waste.name')
                    ->label(__('hazardousMaterialsExperience.collection_hazardous_waste'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('training_others_on_hazardous_waste.name')
                    ->label(__('hazardousMaterialsExperience.training_others_on_hazardous_waste'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListHazardousMaterialsExperiences::route('/'),
            // 'create' => Pages\CreateHazardousMaterialsExperience::route('/create'),
            // 'edit' => Pages\EditHazardousMaterialsExperience::route('/{record}/edit'),
        ];
    }    
}
