<?php

namespace App\Filament\Resources\UserDataResource\RelationManagers;

use App\Filament\Resources\DeploymentOpportunityResource;
use App\Filament\Resources\UserDataResource;
use App\Models\User;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Notifications\Notification;
use Filament\Resources\RelationManagers\RelationManager;
use App\Models\DeploymentApplication;
use App\Models\DeploymentOpportunity;
use App\Models\UserData;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class AdminDeploymentApplicationRelationManager extends RelationManager
{
    protected static string $relationship = 'admin_deployment_application';

    public function form(Form $form): Form
    {
        return $form
            ->schema([
                // Forms\Components\TextInput::make('id')
                //     ->required()
                //     ->maxLength(255),
                    
                Forms\Components\Select::make('user_response')
                    ->options([
                        'Yes' => 'Yes',
                        'No' => 'No',
                    ])
                    ->required(),
                Forms\Components\Select::make('status')
                    ->options([
                        'Pending' => 'Pending',
                        'Approved' => 'Approved',
                        'Denied' => 'Denied'
                    ])
                    ->required()
                    ->hidden(! auth()->user()->hasAnyRole(['Admin','Deployment_opportunities_creator']))
,
                
            ]);
    }

    public function table(Table $table): Table
    {
        return $table
            ->recordTitleAttribute('id')
            ->columns([
                Tables\Columns\TextColumn::make('id'),
                Tables\Columns\TextColumn::make('event_name'),
                Tables\Columns\TextColumn::make('status'),
                Tables\Columns\TextColumn::make('user_response'),
                Tables\Columns\TextColumn::make('id'),

            ])
            ->filters([
                //
            ])
            ->headerActions([
                //Tables\Actions\CreateAction::make(),
            ])
            ->actions([
                Tables\Actions\EditAction::make()
                ->hidden(!auth()->user()->hasAnyRole('Admin')),
                Tables\Actions\EditAction::make()
                    ->label('Respond')
                    ->hidden(auth()->user()->hasAnyRole('Admin'))
                    ->after(function(DeploymentOpportunity $record){
                            $user = auth()->user();
                            Notification::make()
                                ->title('Application Status')
                                ->body('You have selected ' . $record->user_response . ' for the deployment opportunity '. $record->event_name . '. Admin approval is currently '. $record->status . '.')
                                ->sendToDatabase($user); 
                            Notification::make()
                                ->success()
                                ->title('Application Status')
                                ->icon('heroicon-o-document-text') 
                                ->iconColor('success') 
                                ->body($user->name . ' has selected '. $record->user_response.' for the deployment opportunity '. $record->event_name.' Your approval is currently '. $record->status . '.')
                                ->sendToDatabase(User::role('Admin')->get()); 
                            // TODO: Add email on this
                    })
                
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
                Tables\Actions\DeleteAction::make(),
            ]);
    }
}
