<?php

namespace App\Filament\Resources;

use App\Filament\Resources\WaterSanitationHygieneWashResource\Pages;
use App\Filament\Resources\WaterSanitationHygieneWashResource\RelationManagers;
use App\Models\WaterSanitationHygieneWash;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class WaterSanitationHygieneWashResource extends Resource
{
    protected static ?string $model = WaterSanitationHygieneWash::class;

    public static function getModelLabel(): string
    {
        return __('waterSanitation.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('in_healthcare_settings_id')
                    ->label(__('waterSanitation.in_healthcare_settings'))
                    ->relationship('in_healthcare_settings', 'name')
                    ->required(),
                Forms\Components\Select::make('in_a_non_medical_id')
                    ->label(__('waterSanitation.in_a_non_medical'))
                    ->relationship('in_a_non_medical', 'name')
                    ->required(),
                Forms\Components\Select::make('source_water_assessment_id')
                    ->label(__('waterSanitation.source_water_assessment'))
                    ->relationship('source_water_assessment', 'name')
                    ->required(),
                Forms\Components\Select::make('water_analysis_id')
                    ->label(__('waterSanitation.water_analysis'))
                    ->relationship('water_analysis', 'name')
                    ->required(),
                Forms\Components\Select::make('train_others_on_water_testing_and_aquatab_id')
                    ->label(__('waterSanitation.train_others_on_water_testing_and_aquatab'))
                    ->relationship('train_others_on_water_testing_and_aquatab', 'name')
                    ->required(),
                Forms\Components\Select::make('water_infrastructure_mapping_id')
                    ->label(__('waterSanitation.water_infrastructure_mapping'))
                    ->relationship('water_infrastructure_mapping', 'name')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('in_healthcare_settings.name')
                    ->label(__('waterSanitation.in_healthcare_settings'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('in_a_non_medical.name')
                    ->label(__('waterSanitation.in_a_non_medical'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('source_water_assessment.name')
                    ->label(__('waterSanitation.source_water_assessment'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('water_analysis.name')
                    ->label(__('waterSanitation.water_analysis'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('train_others_on_water_testing_and_aquatab.name')
                    ->label(__('waterSanitation.train_others_on_water_testing_and_aquatab'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('water_infrastructure_mapping.name')
                    ->label(__('waterSanitation.water_infrastructure_mapping'))
                    ->numeric()
                    ->sortable(),
                    Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListWaterSanitationHygieneWashes::route('/'),
            'create' => Pages\CreateWaterSanitationHygieneWash::route('/create'),
            'edit' => Pages\EditWaterSanitationHygieneWash::route('/{record}/edit'),
        ];
    }    
}
