<?php

namespace App\Filament\Widgets;

use App\Models\DeploymentApplication;
use Filament\Forms;
use Filament\Tables;
use Filament\Tables\Actions\EditAction;
use Filament\Tables\Table;
use Filament\Widgets\TableWidget as BaseWidget;
    
class latestApplications extends BaseWidget
{
    protected int | string | array $columnSpan = 'full';
    protected static ?int $sort = 4;

    public function table(Table $table): Table
    {
        return $table
            ->query(
                DeploymentApplication::latest()->limit(5)
            )
            ->columns([
                Tables\Columns\TextColumn::make('deployment_opportunity.event_name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable()
                    ->hidden(!auth()->user()->hasAnyRole('Admin')),
                Tables\Columns\TextColumn::make('status')
                    ->colors([
                        'primary',
                        'warning' => 'Pending',
                        'success' => 'Approved',
                        'danger' => 'Denied'
                    ])
                    ->searchable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable(),
                    ])
            
            ->actions([
                Tables\Actions\ViewAction::make()
                ->form([
                Forms\Components\Select::make('deployment_opportunity_id')
                     ->relationship('deployment_opportunity', 'event_name')
                     ->label(__('deploymentApplication.deploymentopportunity')),
                     //->options(DeploymentOpportunity::where('user_id',NULL)->pluck('event_name','id')),
                Forms\Components\Select::make('status')
                    ->options([
                        'Pending' => 'Pending',
                        'Approved' => 'Approved',
                        'Denied' => 'Denied'
                ])
                ->hidden(! auth()->user()->hasAnyRole('Admin'))
                ->default('pending')
                ->saveRelationshipsWhenHidden()
                ->label(__('deploymentApplication.status')),
                
                Forms\Components\Select::make('user')
                ->relationship('user', 'name')
                ->multiple()
                ->preload()
                ->hidden(! auth()->user()->hasAnyRole('Admin')) 
                ->label(__('deploymentApplication.user'))              
                
            ]),
            EditAction::make()
                ->hidden(!auth()->user()->hasAnyRole('Admin'))
                ->form([
                Forms\Components\Select::make('deployment_opportunity_id')
                     ->relationship('deployment_opportunity', 'event_name')
                     ->label(__('deploymentApplication.deploymentopportunity')),
                     //->options(DeploymentOpportunity::where('user_id',NULL)->pluck('event_name','id')),
                Forms\Components\Select::make('status')
                    ->options([
                        'Pending' => 'Pending',
                        'Approved' => 'Approved',
                        'Denied' => 'Denied'
                ])
                ->hidden(! auth()->user()->hasAnyRole('Admin'))
                ->default('pending')
                ->saveRelationshipsWhenHidden()
                ->label(__('deploymentApplication.status')),
                
                Forms\Components\Select::make('user')
                ->relationship('user', 'name')
                ->multiple()
                ->preload()
                ->hidden(! auth()->user()->hasAnyRole('Admin')) 
                ->label(__('deploymentApplication.user'))              
                
            ]),
            ]);
    }
}
