<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Models\Traits\Multitenantable;

class ExperienceInEpidemiology extends Model
{
    use SoftDeletes;
    use HasFactory;
    use Multitenantable;

    public $table = 'experience_in_epidemiologies';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'rapid_risk_assessments_id',
        'monitoring_system_id',
        'epidemic_survey_id',
        'determination_of_disease_status_id',
        'contact_tracing_id',
        'case_management_id',
        'epidemiological_studies_id',
        'study_protocols_id',
        'data_collection_tools_id',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function rapid_risk_assessments()
    {
        return $this->belongsTo(TrainingLevel::class, 'rapid_risk_assessments_id');
    }

    public function monitoring_system()
    {
        return $this->belongsTo(TrainingLevel::class, 'monitoring_system_id');
    }

    public function epidemic_survey()
    {
        return $this->belongsTo(TrainingLevel::class, 'epidemic_survey_id');
    }

    public function determination_of_disease_status()
    {
        return $this->belongsTo(TrainingLevel::class, 'determination_of_disease_status_id');
    }

    public function contact_tracing()
    {
        return $this->belongsTo(TrainingLevel::class, 'contact_tracing_id');
    }

    public function case_management()
    {
        return $this->belongsTo(TrainingLevel::class, 'case_management_id');
    }

    public function epidemiological_studies()
    {
        return $this->belongsTo(TrainingLevel::class, 'epidemiological_studies_id');
    }

    public function study_protocols()
    {
        return $this->belongsTo(TrainingLevel::class, 'study_protocols_id');
    }

    public function data_collection_tools()
    {
        return $this->belongsTo(TrainingLevel::class, 'data_collection_tools_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
